@@ -11,26 +11,31 @@ setMethod(".gtext",
           signature(toolkit="guiWidgetsToolkittcltk"),
           function(toolkit,
                    text=NULL,
-                   width=NULL, height=300,
+                   width=NULL, height=200,
                    font.attr = NULL, wrap = TRUE,
                    handler = NULL, action=NULL,
                    container=NULL, ...) {
 
 
             force(toolkit)
-
+            theArgs <- list(...)
+            ladd <- function(...,bg) add(...) # don't pass bg to add -- if present
 
             if(is(container,"logical") && container)
-              container = gwindow()
+              container <- gwindow()
             if(!is(container,"guiWidget")) {
               warning("Container is not correct. No NULL containers possible\n" )
               return()
             }
 
-            tt = getBlock(container)
-            gp = ttkframe(tt)
-
-            if(wrap) wrap="word" else wrap="none"
+            ## options
+            ## wrap
+            if(wrap) wrap <- "word" else wrap <- "none"
+            ## background color
+            bg <- if(!is.null(theArgs$bg)) theArgs$bg else "white"
+            
+            tt <- getWidget(container)
+            gp <- ttkframe(tt)
             
             xscr <- ttkscrollbar(gp, orient="horizontal",
                                  command=function(...)tkxview(txt,...))
@@ -38,7 +43,7 @@ setMethod(".gtext",
                                  command=function(...)tkyview(txt,...))
             
             txt <- tktext(gp,
-                          bg="white", setgrid=FALSE, #font="courier",
+                          bg=bg, setgrid=FALSE, #font="courier",
                           undo = TRUE,                  # undo support
                           xscrollcommand=function(...)tkset(xscr,...),
                           yscrollcommand=function(...)tkset(yscr,...),
@@ -52,10 +57,14 @@ setMethod(".gtext",
             tkgrid.columnconfigure(gp, 0, weight=1)
             tkgrid.rowconfigure(gp, 0, weight=1)
 
+            ## call in autoscroll
+            tcl("autoscroll", xscr)
+            tcl("autoscroll", yscr)
+            
             ## set point
             tkmark.set(txt,"insert","0.0")
             
-            obj = new("gTexttcltk", block=gp, widget=txt, tags=list(),
+            obj <- new("gTexttcltk", block=gp, widget=txt, tags=list(),
               toolkit=toolkit,ID=getNewID(), e = new.env())
 
 
@@ -73,14 +82,15 @@ setMethod(".gtext",
 
             
             ## attach to container
-              add(container, obj,...)
+            add(container, obj,...)
 
             ## add handler
             if (!is.null(handler)) {
-              id = addhandlerkeystroke(obj, handler, action)
+              obj@e$handler.id <- addhandlerkeystroke(obj, handler, action)
             }
             return(obj)
           })
+
 ## drop=TRUE to get only mouse selected text
 setMethod(".svalue",
           signature(toolkit="guiWidgetsToolkittcltk",obj="gTexttcltk"),
@@ -92,10 +102,10 @@ setMethod(".svalue",
               ## get the selected text from gtext,
               ## return the index instead of text.
               if(tclvalue(tktag.ranges(getWidget(obj),"sel")) != ""){
-                val = strsplit(tclvalue(tktag.ranges(getWidget(obj),
+                val <- strsplit(tclvalue(tktag.ranges(getWidget(obj),
                   "sel")), " ")[[1]]}
               else
-                val =c(0,0)
+                val <- c(0,0)
               return(as.numeric(val))
             }
 
@@ -103,16 +113,16 @@ setMethod(".svalue",
             ## if drop=FALSE or NULL grab all text
             ## if drop=TRUE, get selected text only
             if(is.null(drop) || drop == FALSE) {
-              val = tclvalue(tkget(getWidget(obj),"0.0","end"))
+              val <-  tclvalue(tkget(getWidget(obj),"0.0","end"))
               ## strip off last "\n"'s
               val <- gsub("\n*$","",val)
             } else {
               range <- as.numeric(tktag.ranges(getWidget(obj),"sel"))
               ## range is numeric(0) if none
               if(length(range) > 0)
-                val = tclvalue(tkget(getWidget(obj),"sel.first","sel.last"))
+                val <- tclvalue(tkget(getWidget(obj),"sel.first","sel.last"))
               else
-                val = ""
+                val <- ""
             }
                                         ## val = unlist(strsplit(val,"\n"))
             return(val)
@@ -127,7 +137,7 @@ setReplaceMethod(".svalue",
                    tkdelete(getWidget(obj),"0.0","end")
 
                    if(length(value) > 1)
-                     value = paste(value, collapse="\n")
+                     value <- paste(value, collapse="\n")
                    tkinsert(getWidget(obj),"end",value)
                             
                    return(obj)
@@ -153,46 +163,57 @@ setMethod(".dispose",
 ## add, as a method, needs to have a consistent signature. I'
 
 ## add text
+setMethod(".insert",
+          signature(toolkit="guiWidgetsToolkittcltk",obj = "gTexttcltk"),
+          function(obj, toolkit, value, where = c("end","beginning","at.cursor"),
+                   font.attr = NULL,
+                   do.newline = TRUE, ...) {
+            ## just call add
+            where <- match.arg(where)
+            .add(obj, toolkit, value, where=where, font.attr=font.attr,
+                 do.newline=do.newline, ...)
+          })
+
 setMethod(".add",
           signature(toolkit="guiWidgetsToolkittcltk",obj="gTexttcltk",value="character"),
           function(obj, toolkit, value,  ...) {
-            theArgs = list(...)                      # look for font.attr, do.newline, where
+            theArgs <- list(...)                      # look for font.attr, do.newline, where
 
-            do.newline = ifelse(is.null(theArgs$do.newline), TRUE, as.logical(theArgs$do.newline))
+            do.newline <- ifelse(is.null(theArgs$do.newline), TRUE, as.logical(theArgs$do.newline))
 
 
             
-            where = ifelse(is.null(theArgs$where), "end",theArgs$where)
-            if(where != "end") where = "0.0"
+            where <- ifelse(is.null(theArgs$where), "end",theArgs$where)
+            if(where != "end") where = "0.0" ## the beginning
             
-            value = paste(value,collapse="\n")
+            value <- paste(value,collapse="\n")
             if(do.newline)
               value = paste(value,"\n",sep="")
 
             ### Handle markup here
-            markup = theArgs$font.attr
+            markup <- theArgs$font.attr
             if(!is.null(markup) && !is.list(markup))
-              markup = lapply(markup,function(x) x)
+              markup <- lapply(markup,function(x) x)
             
             if(!is.null(markup)) {
               ## set up tag for handling markup
-              argList = list(getWidget(obj),"foo")
-              fontList = c()
+              argList <- list(getWidget(obj),"foo")
+              fontList <- c()
               if(!is.null(markup$family))
-                fontList = c(fontList,family=switch(markup$family,
+                fontList <- c(fontList,family=switch(markup$family,
                                         "normal"="times",
                                         "sans" = "helvetica",
                                         "serif" = "times",
                                         "monospace"="courier",
                                         markup$family))
               if(!is.null(markup$weight))
-                fontList = c(fontList,slant=switch(markup$weight,
+                fontList <- c(fontList,slant=switch(markup$weight,
                                         "normal"="normal",
                                         "oblique"="normal",
                                         "italic"="italic",
                                         markup$weight))
               if(!is.null(markup$style))
-                fontList = c(fontList, weight=switch(markup$style,
+                fontList <- c(fontList, weight=switch(markup$style,
                                          "bold"="bold",
                                          "ultra-bold"="bold",
                                          "heavy"="bold",
@@ -200,9 +221,9 @@ setMethod(".add",
               
               if(!is.null(markup$size))
                 if(is.numeric(markup$size))
-                  fontList = c(fontList, size=markup$size)
+                  fontList <- c(fontList, size=markup$size)
                 else
-                  fontList = c(fontList,size = switch(markup$size,
+                  fontList <- c(fontList,size = switch(markup$size,
                                           "xxx-large"=24,
                                           "xx-large"=20,
                                           "x-large"=18,
@@ -226,7 +247,7 @@ setMethod(".add",
               tkinsert(getWidget(obj),where,value,"foo")
 
               ## does this place the cursor? TK FAQ 10.6
-              tksee(getWidget(obj),"end")
+              tksee(getWidget(obj),where) # where = "end" or "0.0"
               
             } else {
               ## no markup
